@@ -1,7 +1,10 @@
 import requests
 from requests import RequestException
 
+from qiwipyapi.utils import retry
 
+
+@retry(RequestException, tries=3, delay=5)
 def request(method, request_url, **kwargs):
     try:
         response = requests.Session().request(method=method, url=request_url, headers=kwargs.get('headers'),
